==> koffice-1.2.1-i386-3.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkwmf.so )
( cd opt/kde/lib ; ln -sf libkwmf.so.2.0.0 libkwmf.so )
( cd opt/kde/lib/kde3 ; rm -rf libkarbonaiimport.so )
( cd opt/kde/lib/kde3 ; ln -sf libkarbonaiimport.so.1.0.0 libkarbonaiimport.so )
( cd opt/kde/lib/kde3 ; rm -rf libkarbonaiimport.so.1 )
( cd opt/kde/lib/kde3 ; ln -sf libkarbonaiimport.so.1.0.0 libkarbonaiimport.so.1 )
( cd opt/kde/lib ; rm -rf libkwordexportfilters.so )
( cd opt/kde/lib ; ln -sf libkwordexportfilters.so.1.0.0 libkwordexportfilters.so )
( cd opt/kde/lib ; rm -rf libkofficecore.so )
( cd opt/kde/lib ; ln -sf libkofficecore.so.2.0.0 libkofficecore.so )
( cd opt/kde/lib ; rm -rf libkotext.so )
( cd opt/kde/lib ; ln -sf libkotext.so.2.0.0 libkotext.so )
( cd opt/kde/lib ; rm -rf libkdchart.so )
( cd opt/kde/lib ; ln -sf libkdchart.so.0.0.0 libkdchart.so )
( cd opt/kde/lib ; rm -rf libkformula.so )
( cd opt/kde/lib ; ln -sf libkformula.so.3.0.0 libkformula.so )
( cd opt/kde/lib ; rm -rf libkopainter.so )
( cd opt/kde/lib ; ln -sf libkopainter.so.1.0.0 libkopainter.so )
( cd opt/kde/lib ; rm -rf libkoscript.so )
( cd opt/kde/lib ; ln -sf libkoscript.so.2.0.0 libkoscript.so )
( cd opt/kde/lib ; rm -rf libkwmailmerge_interface.so.4 )
( cd opt/kde/lib ; ln -sf libkwmailmerge_interface.so.4.0.0 libkwmailmerge_interface.so.4 )
( cd opt/kde/lib ; rm -rf libkochart.so )
( cd opt/kde/lib ; ln -sf libkochart.so.1.0.0 libkochart.so )
( cd opt/kde/lib ; rm -rf libkugar.so.1 )
( cd opt/kde/lib ; ln -sf libkugar.so.1.0.2 libkugar.so.1 )
( cd opt/kde/lib ; rm -rf libkwmailmerge_interface.so )
( cd opt/kde/lib ; ln -sf libkwmailmerge_interface.so.4.0.0 libkwmailmerge_interface.so )
( cd opt/kde/lib ; rm -rf libkoscript.so.2 )
( cd opt/kde/lib ; ln -sf libkoscript.so.2.0.0 libkoscript.so.2 )
( cd opt/kde/lib ; rm -rf libkdchart.so.0 )
( cd opt/kde/lib ; ln -sf libkdchart.so.0.0.0 libkdchart.so.0 )
( cd opt/kde/lib ; rm -rf libkopainter.so.1 )
( cd opt/kde/lib ; ln -sf libkopainter.so.1.0.0 libkopainter.so.1 )
( cd opt/kde/lib ; rm -rf libkofficeui.so.2 )
( cd opt/kde/lib ; ln -sf libkofficeui.so.2.0.0 libkofficeui.so.2 )
( cd opt/kde/lib ; rm -rf libkofficecore.so.2 )
( cd opt/kde/lib ; ln -sf libkofficecore.so.2.0.0 libkofficecore.so.2 )
( cd opt/kde/lib ; rm -rf libkochart.so.1 )
( cd opt/kde/lib ; ln -sf libkochart.so.1.0.0 libkochart.so.1 )
( cd opt/kde/lib ; rm -rf libkstore.so )
( cd opt/kde/lib ; ln -sf libkstore.so.2.0.0 libkstore.so )
( cd opt/kde/lib ; rm -rf libkofficeui.so )
( cd opt/kde/lib ; ln -sf libkofficeui.so.2.0.0 libkofficeui.so )
( cd opt/kde/lib ; rm -rf libkugar.so )
( cd opt/kde/lib ; ln -sf libkugar.so.1.0.2 libkugar.so )
( cd opt/kde/lib ; rm -rf libkwmf.so.2 )
( cd opt/kde/lib ; ln -sf libkwmf.so.2.0.0 libkwmf.so.2 )
( cd opt/kde/lib ; rm -rf libkwordexportfilters.so.1 )
( cd opt/kde/lib ; ln -sf libkwordexportfilters.so.1.0.0 libkwordexportfilters.so.1 )
( cd opt/kde/lib ; rm -rf libkformula.so.3 )
( cd opt/kde/lib ; ln -sf libkformula.so.3.0.0 libkformula.so.3 )
( cd opt/kde/lib ; rm -rf libkstore.so.2 )
( cd opt/kde/lib ; ln -sf libkstore.so.2.0.0 libkstore.so.2 )
( cd opt/kde/lib ; rm -rf libkotext.so.2 )
( cd opt/kde/lib ; ln -sf libkotext.so.2.0.0 libkotext.so.2 )
( cd opt/kde/share/doc/HTML/en/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kugar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kword ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koffice ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koshell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspread ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koffice-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koffice-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kchart ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpresenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/thesaurus ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kformula ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> koffice-1.3.1-i486-4.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkwmf.so )
( cd opt/kde/lib ; ln -sf libkwmf.so.2.0.0 libkwmf.so )
( cd opt/kde/lib/kde3 ; rm -rf libkarbonaiimport.so )
( cd opt/kde/lib/kde3 ; ln -sf libkarbonaiimport.so.1.0.0 libkarbonaiimport.so )
( cd opt/kde/lib/kde3 ; rm -rf libkarbonaiimport.so.1 )
( cd opt/kde/lib/kde3 ; ln -sf libkarbonaiimport.so.1.0.0 libkarbonaiimport.so.1 )
( cd opt/kde/lib ; rm -rf libkwordexportfilters.so )
( cd opt/kde/lib ; ln -sf libkwordexportfilters.so.1.0.0 libkwordexportfilters.so )
( cd opt/kde/lib ; rm -rf libkofficecore.so )
( cd opt/kde/lib ; ln -sf libkofficecore.so.2.0.0 libkofficecore.so )
( cd opt/kde/lib ; rm -rf libkotext.so )
( cd opt/kde/lib ; ln -sf libkotext.so.2.0.0 libkotext.so )
( cd opt/kde/lib ; rm -rf libkowmf.so )
( cd opt/kde/lib ; ln -sf libkowmf.so.1.0.0 libkowmf.so )
( cd opt/kde/lib ; rm -rf libkdchart.so )
( cd opt/kde/lib ; ln -sf libkdchart.so.0.0.0 libkdchart.so )
( cd opt/kde/lib ; rm -rf libkowmf.so.1 )
( cd opt/kde/lib ; ln -sf libkowmf.so.1.0.0 libkowmf.so.1 )
( cd opt/kde/lib ; rm -rf libkformula.so )
( cd opt/kde/lib ; ln -sf libkformula.so.3.0.0 libkformula.so )
( cd opt/kde/lib ; rm -rf libkopainter.so )
( cd opt/kde/lib ; ln -sf libkopainter.so.1.0.0 libkopainter.so )
( cd opt/kde/lib ; rm -rf libkospell.so )
( cd opt/kde/lib ; ln -sf libkospell.so.4.1.0 libkospell.so )
( cd opt/kde/lib ; rm -rf libkoscript.so )
( cd opt/kde/lib ; ln -sf libkoscript.so.2.0.0 libkoscript.so )
( cd opt/kde/lib ; rm -rf libkwmailmerge_interface.so.4 )
( cd opt/kde/lib ; ln -sf libkwmailmerge_interface.so.4.0.0 libkwmailmerge_interface.so.4 )
( cd opt/kde/lib ; rm -rf libkochart.so )
( cd opt/kde/lib ; ln -sf libkochart.so.1.0.0 libkochart.so )
( cd opt/kde/lib ; rm -rf libkugar.so.1 )
( cd opt/kde/lib ; ln -sf libkugar.so.1.0.2 libkugar.so.1 )
( cd opt/kde/lib ; rm -rf libkwmailmerge_interface.so )
( cd opt/kde/lib ; ln -sf libkwmailmerge_interface.so.4.0.0 libkwmailmerge_interface.so )
( cd opt/kde/lib ; rm -rf libkoscript.so.2 )
( cd opt/kde/lib ; ln -sf libkoscript.so.2.0.0 libkoscript.so.2 )
( cd opt/kde/lib ; rm -rf libkdchart.so.0 )
( cd opt/kde/lib ; ln -sf libkdchart.so.0.0.0 libkdchart.so.0 )
( cd opt/kde/lib ; rm -rf libkopainter.so.1 )
( cd opt/kde/lib ; ln -sf libkopainter.so.1.0.0 libkopainter.so.1 )
( cd opt/kde/lib ; rm -rf libkofficeui.so.2 )
( cd opt/kde/lib ; ln -sf libkofficeui.so.2.0.0 libkofficeui.so.2 )
( cd opt/kde/lib ; rm -rf libkofficecore.so.2 )
( cd opt/kde/lib ; ln -sf libkofficecore.so.2.0.0 libkofficecore.so.2 )
( cd opt/kde/lib ; rm -rf libkochart.so.1 )
( cd opt/kde/lib ; ln -sf libkochart.so.1.0.0 libkochart.so.1 )
( cd opt/kde/lib ; rm -rf libkstore.so )
( cd opt/kde/lib ; ln -sf libkstore.so.2.0.0 libkstore.so )
( cd opt/kde/lib ; rm -rf libkofficeui.so )
( cd opt/kde/lib ; ln -sf libkofficeui.so.2.0.0 libkofficeui.so )
( cd opt/kde/lib ; rm -rf libkospell.so.4 )
( cd opt/kde/lib ; ln -sf libkospell.so.4.1.0 libkospell.so.4 )
( cd opt/kde/lib ; rm -rf libkugar.so )
( cd opt/kde/lib ; ln -sf libkugar.so.1.0.2 libkugar.so )
( cd opt/kde/lib ; rm -rf libkwmf.so.2 )
( cd opt/kde/lib ; ln -sf libkwmf.so.2.0.0 libkwmf.so.2 )
( cd opt/kde/lib ; rm -rf libkwordexportfilters.so.1 )
( cd opt/kde/lib ; ln -sf libkwordexportfilters.so.1.0.0 libkwordexportfilters.so.1 )
( cd opt/kde/lib ; rm -rf libkformula.so.3 )
( cd opt/kde/lib ; ln -sf libkformula.so.3.0.0 libkformula.so.3 )
( cd opt/kde/lib ; rm -rf libkstore.so.2 )
( cd opt/kde/lib ; ln -sf libkstore.so.2.0.0 libkstore.so.2 )
( cd opt/kde/lib ; rm -rf libkotext.so.2 )
( cd opt/kde/lib ; ln -sf libkotext.so.2.0.0 libkotext.so.2 )
( cd opt/kde/share/doc/HTML/en/kivio ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kivio ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kugar ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kugar ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kword ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kword ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koffice ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koffice ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koshell ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koshell ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kspread ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kspread ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/koffice-apidocs ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/koffice-apidocs ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kchart ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kchart ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpresenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpresenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/thesaurus ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/thesaurus ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kformula ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kformula ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/apps/kivio/autoloadStencils ; rm -rf straight_connector.so )
( cd opt/kde/share/apps/kivio/autoloadStencils ; ln -sf /opt/kde/lib/kde3/straight_connector.so straight_connector.so )
